# myocr
Welcome to myocr! Let's grade your answer sheets.

## Setup

```
pip install myocr
```

## Forword

1. go to (notebook)[notebook]
2. run forward in demo.ipynb

## Train

The demo notebook provide retrain process.
Note that you need to run Label Studio before retaining.

```
docker-compose up
```